@@ -163,6 +163,12 @@ def test_apng_blend():
         assert im.getpixel((64, 32)) == (0, 255, 0, 255)
 
 
+def test_apng_blend_transparency():
+    with Image.open("Tests/images/blend_transparency.png") as im:
+        im.seek(1)
+        assert im.getpixel((0, 0)) == (255, 0, 0)
+
+
 def test_apng_chunk_order():
     with Image.open("Tests/images/apng/fctl_actl.png") as im:
         im.seek(im.n_frames - 1)
@@ -263,13 +269,11 @@ def test_apng_chunk_errors():
     with Image.open("Tests/images/apng/chunk_no_actl.png") as im:
         assert not im.is_animated
 
-    def open():
+    with pytest.warns(UserWarning):
         with Image.open("Tests/images/apng/chunk_multi_actl.png") as im:
             im.load()
         assert not im.is_animated
 
-    pytest.warns(UserWarning, open)
-
     with Image.open("Tests/images/apng/chunk_actl_after_idat.png") as im:
         assert not im.is_animated
 
@@ -287,21 +291,17 @@ def test_apng_chunk_errors():
 
 
 def test_apng_syntax_errors():
-    def open_frames_zero():
+    with pytest.warns(UserWarning):
         with Image.open("Tests/images/apng/syntax_num_frames_zero.png") as im:
             assert not im.is_animated
             with pytest.raises(OSError):
                 im.load()
 
-    pytest.warns(UserWarning, open_frames_zero)
-
-    def open_frames_zero_default():
+    with pytest.warns(UserWarning):
         with Image.open("Tests/images/apng/syntax_num_frames_zero_default.png") as im:
             assert not im.is_animated
             im.load()
 
-    pytest.warns(UserWarning, open_frames_zero_default)
-
     # we can handle this case gracefully
     exception = None
     with Image.open("Tests/images/apng/syntax_num_frames_low.png") as im:
@@ -316,13 +316,11 @@ def test_apng_syntax_errors():
             im.seek(im.n_frames - 1)
             im.load()
 
-    def open():
+    with pytest.warns(UserWarning):
         with Image.open("Tests/images/apng/syntax_num_frames_invalid.png") as im:
             assert not im.is_animated
             im.load()
 
-    pytest.warns(UserWarning, open)
-
 
 @pytest.mark.parametrize(
     "test_file",
@@ -376,6 +374,20 @@ def test_apng_save(tmp_path):
         assert im.getpixel((64, 32)) == (0, 255, 0, 255)
 
 
+def test_apng_save_alpha(tmp_path):
+    test_file = str(tmp_path / "temp.png")
+
+    im = Image.new("RGBA", (1, 1), (255, 0, 0, 255))
+    im2 = Image.new("RGBA", (1, 1), (255, 0, 0, 127))
+    im.save(test_file, save_all=True, append_images=[im2])
+
+    with Image.open(test_file) as reloaded:
+        assert reloaded.getpixel((0, 0)) == (255, 0, 0, 255)
+
+        reloaded.seek(1)
+        assert reloaded.getpixel((0, 0)) == (255, 0, 0, 127)
+
+
 def test_apng_save_split_fdat(tmp_path):
     # test to make sure we do not generate sequence errors when writing
     # frames with image data spanning multiple fdAT chunks (in this case
@@ -449,6 +461,17 @@ def test_apng_save_duration_loop(tmp_path):
         assert im.info.get("duration") == 750
 
 
+def test_apng_save_duplicate_duration(tmp_path):
+    test_file = str(tmp_path / "temp.png")
+    frame = Image.new("RGB", (1, 1))
+
+    # Test a single duration is correctly combined across duplicate frames
+    frame.save(test_file, save_all=True, append_images=[frame, frame], duration=500)
+    with Image.open(test_file) as im:
+        assert im.n_frames == 1
+        assert im.info.get("duration") == 1500
+
+
 def test_apng_save_disposal(tmp_path):
     test_file = str(tmp_path / "temp.png")
     size = (128, 64)
@@ -657,13 +680,3 @@ def test_different_modes_in_later_frames(mode, tmp_path):
     im.save(test_file, save_all=True, append_images=[Image.new(mode, (1, 1))])
     with Image.open(test_file) as reloaded:
         assert reloaded.mode == mode
-
-
-def test_constants_deprecation():
-    for enum, prefix in {
-        PngImagePlugin.Disposal: "APNG_DISPOSE_",
-        PngImagePlugin.Blend: "APNG_BLEND_",
-    }.items():
-        for name in enum.__members__:
-            with pytest.warns(DeprecationWarning):
-                assert getattr(PngImagePlugin, prefix + name) == enum[name]
