@@ -617,11 +617,12 @@ def test_auxiliary_channels_isolated():
                 assert_image_equal(test_image.convert(dst_format[2]), reference_image)
 
 
-def test_constants_deprecation():
-    for enum, prefix in {
-        ImageCms.Intent: "INTENT_",
-        ImageCms.Direction: "DIRECTION_",
-    }.items():
-        for name in enum.__members__:
-            with pytest.warns(DeprecationWarning):
-                assert getattr(ImageCms, prefix + name) == enum[name]
+@pytest.mark.parametrize("mode", ("RGB", "RGBA", "RGBX"))
+def test_rgb_lab(mode):
+    im = Image.new(mode, (1, 1))
+    converted_im = im.convert("LAB")
+    assert converted_im.getpixel((0, 0)) == (0, 128, 128)
+
+    im = Image.new("LAB", (1, 1), (255, 0, 0))
+    converted_im = im.convert(mode)
+    assert converted_im.getpixel((0, 0))[:3] == (0, 255, 255)
